(define-module (glicid packages nginx)
  #:use-module (guix packages)
  #:use-module (guix utils)
  #:use-module (guix download)
  #:use-module (guix git-download)
  #:use-module (guix build-system gnu)
  #:use-module (gnu packages web)
  #:use-module (glicid packages openldap)
)

(define-public nginx-ldap-auth-module
  (package
    (inherit nginx)
    (name "nginx-ldap-auth-module")
    (version "83c059b73566c2ee9cbda920d91b66657cf120b7")
    (source
      (origin
        (method git-fetch)
        (uri (git-reference
               (url "https://github.com/kvspb/nginx-auth-ldap")
               (commit version)
             )
        )
        (file-name (git-file-name "nginx-ldap-auth-module" version))
        (sha256 (base32 "023zmdir7w92dnb508ggskkc7kmd7k71hc597sb7i4xfgpwxzq1s" ))
      )
    )
    (synopsis "LDAP Authentication module for nginx")
    (description "LDAP module for nginx which supports authentication against multiple LDAP servers.")
    (build-system gnu-build-system)
    (inputs
     `(("nginx-sources" ,(package-source nginx))
       ("openldap", openldap)
       ,@(package-inputs nginx)))
    (arguments
     (substitute-keyword-arguments
         `(#:configure-flags '("--add-dynamic-module=.")
           #:make-flags '("modules")
;           #:modules ((guix build utils)
;                      (guix build gnu-build-system)
;                      (ice-9 popen)
;                      (ice-9 regex)
;                      (ice-9 textual-ports))
           ,@(package-arguments nginx))
       ((#:phases phases)
        `(modify-phases ,phases
           (add-after 'unpack 'unpack-nginx-sources
             (lambda* (#:key inputs native-inputs #:allow-other-keys)
               (begin
                 ;; The nginx source code is part of the module’s source.
                 (format #t "decompressing nginx source code~%")
                 (let ((tar (assoc-ref inputs "tar"))
                       (nginx-srcs (assoc-ref inputs "nginx-sources")))
                   (invoke (string-append tar "/bin/tar")
                           "xvf" nginx-srcs "--strip-components=1"))
                 #t)))
;           (replace 'install
;             (lambda* (#:key outputs #:allow-other-keys)
;               (let ((modules-dir (string-append (assoc-ref outputs "out")
;                                                 "/etc/nginx/modules")))
;                 (install-file "objs/ngx_http_lua_module.so" modules-dir)
;                 #t)))
;           (delete 'fix-root-dirs)
;           (delete 'install-man-page)
))))))



nginx-ldap-auth-module

;(define-public nginx-mod_security
;  (package
;  )
;)
